/*
        writer.cpp
        Mar. 21st, 2006
        Joris Roos <jorisr@gmx.de>
        Writes tokens/ASCII to file
*/

#include "tokenreader.h"

int writeASCIIFile(const char* file)
{
    FILE* fh = fopen(file, "w");
    
    if (fh == 0) return ERROR(FAILED, "could not open file '%s'.", file);
    
    char tmp[BUFSIZE];
    time_t ct = time(NULL);
    
    fprintf(fh, "Token Reader\n(c) Joris Roos, 2006\nContact: jorisr@gmx.de\n\n");
    
        /* write additional information */
    fprintf(fh, "%s\n", tokenfile);                       /* original program file */
    strftime(tmp, BUFSIZE, "%b. %d, %Y", localtime(&ct)); /* date */
    fprintf(fh, "%s\n\n", tmp);                           
    fprintf(fh, "Program: %s\nComment: %s\nSize: %i bytes\nProtected: %s\n",
                prog, comment, tokbuf_l, prot == 6 ? "Yes" : "No"); /* on-calc name,
                                                                       comment,
                                                                       size,
                                                                       protection status */ 

    unsigned char tok1, tok2;
    
    for (int a = 0; a < tokbuf_l; a++) {
        tok1 = tokbuf[a]; 
        tok2 = tokbuf[a+1]; /* this might look like it goes into unallocated
                               memory at a = tokbuf_l - 1, but since tokbuf
                               is exactly one byte longer than tokbuf_l
                               (see reader.cpp), this is perfectly fine */
        int i = 0; /* the current position in the table */
        /* search table for token */
        while (tokens[i].ascii != 0) { /* the last table entry consists entirely
                                          of 0s (see tokens.cpp) to signify the
                                          end of the table */
                                           
            if (tokens[i].tok1 == tok1) /* 1st byte is equivalent,
                                           but it is not yet determined, if
                                           this is a 2-byte-token or not */
                                            
                if (tokens[i].tok2 == tok2 && tokens[i].tok2 != 0xFF 
                    || tokens[i].tok2 == 0xFE)
                { a++; break; }     /* it is a 2-byte-token, and the 2nd byte
                                        is equivalent -> token was found */ 
                
                else if (tokens[i].tok2 == 0xFF) break; /* it's not a 2-byte-token,
                                                           -> token was found */ 
            i++;
        }
        if (tokens[i].ascii == 0)
            fprintf(fh, "%c", tok1);        /* if token was not found, the
                                               literal character is printed
                                               (that way I could also save the space to
                                               include numbers and capital letters
                                               in the table) */  
        else
            fprintf(fh, "%s", tokens[i].ascii); /* output found token */
    }
    
    fclose(fh);
    
    return 1;
}

/* Last Edit: Mar. 22nd, 2006 */
